@@ -5,6 +5,7 @@
 */
 
 #include "exportaddressbookjobinterface.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 
@@ -59,7 +60,7 @@ void ExportAddressbookJobInterface::slotCheckBackupConfig()
 
 QString ExportAddressbookJobInterface::applicationName() const
 {
-    return QStringLiteral("[KAddressBook]");
+    return u"[KAddressBook]"_s;
 }
 
 void ExportAddressbookJobInterface::slotAddressbookJobTerminated()
@@ -78,9 +79,9 @@ void ExportAddressbookJobInterface::slotWriteNextArchiveResource()
         const Utils::AkonadiInstanceInfo agent = mAkonadiInstanceInfo.at(mIndexIdentifier);
         const QString identifier = agent.identifier;
         if (identifier.contains(QLatin1StringView("akonadi_vcarddir_resource_")) || identifier.contains(QLatin1StringView("akonadi_contacts_resource_"))) {
-            const QString archivePath = Utils::addressbookPath() + identifier + QLatin1Char('/');
+            const QString archivePath = Utils::addressbookPath() + identifier + u'/';
 
-            const QString url = resourcePath(identifier, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/contacts/"));
+            const QString url = resourcePath(identifier, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + u"/contacts/"_s);
             if (!mAgentPaths.contains(url)) {
                 if (!url.isEmpty()) {
                     mAgentPaths << url;
@@ -108,8 +109,8 @@ void ExportAddressbookJobInterface::backupConfig()
 {
     setProgressDialogLabel(i18n("Backing up config..."));
 
-    const QString kaddressbookStr(QStringLiteral("kaddressbookrc"));
-    const QString kaddressbookrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + kaddressbookStr;
+    const QString kaddressbookStr(u"kaddressbookrc"_s);
+    const QString kaddressbookrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + u'/' + kaddressbookStr;
     if (QFileInfo::exists(kaddressbookrc)) {
         KSharedConfigPtr kaddressbook = KSharedConfig::openConfig(kaddressbookrc);
 
@@ -118,34 +119,34 @@ void ExportAddressbookJobInterface::backupConfig()
 
         KConfig *kaddressBookConfig = kaddressbook->copyTo(tmp.fileName());
 
-        const QString collectionViewCheckStateStr(QStringLiteral("CollectionViewCheckState"));
+        const QString collectionViewCheckStateStr(u"CollectionViewCheckState"_s);
         if (kaddressBookConfig->hasGroup(collectionViewCheckStateStr)) {
             KConfigGroup group = kaddressBookConfig->group(collectionViewCheckStateStr);
-            const QString selectionKey(QStringLiteral("Selection"));
+            const QString selectionKey(u"Selection"_s);
             convertCollectionListToRealPath(group, selectionKey);
         }
 
-        const QString collectionViewStateStr(QStringLiteral("CollectionViewState"));
+        const QString collectionViewStateStr(u"CollectionViewState"_s);
         if (kaddressBookConfig->hasGroup(collectionViewStateStr)) {
             KConfigGroup group = kaddressBookConfig->group(collectionViewStateStr);
-            QString currentKey(QStringLiteral("Current"));
+            QString currentKey(u"Current"_s);
             convertCollectionToRealPath(group, currentKey);
 
-            currentKey = QStringLiteral("Expansion");
+            currentKey = u"Expansion"_s;
             convertCollectionListToRealPath(group, currentKey);
 
-            currentKey = QStringLiteral("Selection");
+            currentKey = u"Selection"_s;
             convertCollectionToRealPath(group, currentKey);
         }
         kaddressBookConfig->sync();
         backupFile(tmp.fileName(), Utils::configsPath(), kaddressbookStr);
         delete kaddressBookConfig;
     }
-    backupUiRcFile(QStringLiteral("kaddressbookui.rc"), QStringLiteral("kaddressbook"));
+    backupUiRcFile(u"kaddressbookui.rc"_s, u"kaddressbook"_s);
 
-    storeDirectory(QStringLiteral("/kaddressbook/csv-templates/"));
-    storeDirectory(QStringLiteral("/kaddressbook/viewertemplates/"));
-    storeDirectory(QStringLiteral("/kaddressbook/printing/"));
+    storeDirectory(u"/kaddressbook/csv-templates/"_s);
+    storeDirectory(u"/kaddressbook/viewertemplates/"_s);
+    storeDirectory(u"/kaddressbook/printing/"_s);
 
     emitInfo(i18n("Config backup done."));
 }
