@@ -5,6 +5,7 @@
 */
 
 #include "loadlistfromfile.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <QFile>
 #include <QTest>
@@ -20,7 +21,7 @@ LoadListFromFile::LoadListFromFile(const QString &filename)
     const QByteArray content = f.readAll();
     f.close();
     const QString contextStr = QString::fromUtf8(content);
-    mFileList = contextStr.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+    mFileList = contextStr.split(u'\n', Qt::SkipEmptyParts);
     mFileList.sort();
 }
 
